==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/TASKQUALIFICATIONID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "tasklistid",
    "qualificationid"
})
@XmlRootElement(name = "TASKQUALIFICATIONID")
public class TASKQUALIFICATIONID {

    @XmlElement(name = "TASKLISTID", required = true)
    protected TASKLISTID_Type tasklistid;
    @XmlElement(name = "QUALIFICATIONID", required = true)
    protected QUALIFICATIONID_Type qualificationid;

    /**
     * Obtient la valeur de la propriété tasklistid.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getTASKLISTID() {
        return tasklistid;
    }

    /**
     * Définit la valeur de la propriété tasklistid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setTASKLISTID(TASKLISTID_Type value) {
        this.tasklistid = value;
    }

    /**
     * Obtient la valeur de la propriété qualificationid.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public QUALIFICATIONID_Type getQUALIFICATIONID() {
        return qualificationid;
    }

    /**
     * Définit la valeur de la propriété qualificationid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public void setQUALIFICATIONID(QUALIFICATIONID_Type value) {
        this.qualificationid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/TASKQUALIFICATIONID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "tasklistid",
    "qualificationid"
})
@XmlRootElement(name = "TASKQUALIFICATIONID")
public class TASKQUALIFICATIONID {

    @XmlElement(name = "TASKLISTID", required = true)
    protected TASKLISTID_Type tasklistid;
    @XmlElement(name = "QUALIFICATIONID", required = true)
    protected QUALIFICATIONID_Type qualificationid;

    /**
     * Gets the value of the tasklistid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getTASKLISTID() {
        return tasklistid;
    }

    /**
     * Sets the value of the tasklistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setTASKLISTID(TASKLISTID_Type value) {
        this.tasklistid = value;
    }

    /**
     * Gets the value of the qualificationid property.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public QUALIFICATIONID_Type getQUALIFICATIONID() {
        return qualificationid;
    }

    /**
     * Sets the value of the qualificationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public void setQUALIFICATIONID(QUALIFICATIONID_Type value) {
        this.qualificationid = value;
    }

}
